#
# spec file for package python-google-cloud-storage
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-google-cloud-storage
Version:        1.23.0
Release:        5.3.2
Summary:        Google Cloud Storage API python client library
License:        Apache-2.0
URL:            https://github.com/GoogleCloudPlatform/google-cloud-python
Source:         https://files.pythonhosted.org/packages/source/g/google-cloud-storage/google-cloud-storage-%{version}.tar.gz
BuildRequires:  %{python_module google-auth >= 1.2.0}
BuildRequires:  %{python_module google-cloud-core >= 1.0.3}
BuildRequires:  %{python_module google-resumable-media >= 0.5.0}
BuildRequires:  %{python_module mock >= 3.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-auth >= 1.2.0
Requires:       python-google-cloud-core >= 1.0.3
Requires:       python-google-resumable-media >= 0.5.0
BuildArch:      noarch
%python_subpackages

%description
Python Client for Google Cloud Storage

%prep
%setup -q -n google-cloud-storage-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# skipped tests need the credentials set up
%pytest tests/unit -k 'not (test_conformance_post_policy or test_get_signed_policy_v4 or test_create)'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Mon Jun 29 2020 sean.marlow@suse.com
- Update to 1.23.0:
  * Move create_bucket implementation from Bucket to Client.
  * Add opt-in raw download support.
  * Fix query-string order dependent assert.
  * Normalize VPCSC configuration in system tests.
- Update to 1.22.0:
  * Add UBLA attrs to IAMConfiguration.
- Update to 1.21.0:
  * Add gcloud-python header to user agent.
  * Don't report a gapic version for storage.
  * Update storage endpoint from www.googleapis.com to
    storage.googleapis.com.
  * Call anonymous client method to remove dependency of google
    application credentials.
  * Enable CSEK w/ V4 signed URLs.
  * Support predefined ACLs in Bucket.create.
- Update to 1.20.0:
  * Add user_project param to HMAC-related methods.
  * Add Blob.from_string and Bucket.from_string factories.
  * Add support for STORAGE_EMULATOR_HOST; add benchwrapper script.
* Thu Sep 26 2019 tchvatal@suse.com
- Update to 1.19.1:
  * Minor bugfix over previous release
* Thu Sep 12 2019 tchvatal@suse.com
- Update to 1.19.0:
  * Huge range of updates and tweaks, mostly bugfixing
* Thu May 16 2019 gyee@suse.com
- Update to version 1.15.1
  * Widen range for 'google-cloud-core'
- Update to version 1.15.0
  * New Features
  - Add support for V4 signed URLs
  - Add generation arguments to bucket / blob methods
  * Implementation Changes
  - Remove classifier for Python 3.4 for end-of-life
  - Ensure that 'Blob.reload' passes encryption headers
  * Documentation
  - Update client library documentation URLs
  * Iternal / Testing Changes
  - Fix failing system tests
  - Increase number of retries for 429 errors
  - Un-flake KMS integration tests expecting empty bucket
* Mon Feb 18 2019 jayvdb@gmail.com
- Activate test suite
- Increase minimum versions:
  * google-api-core >= 0.6.1
  * google-cloud-core >= 0.29.0
- Adds new dependency google-cloud-kms
- Update to version 1.14.0
  * New Features
  - Add 'Bucket.iam_configuration' property, enabling Bucket-Policy-Only.
  * Documentation
  - Improve docs for 'generate_signed_url'
- from 1.13.2
  * Implementation Changes
  - Update Blob.update_storage_class to support rewrite tokens.
  * Internal / Testing Changes
  - Skip signing tests for insufficient credentials
  - Document Python 2 deprecation
  - Normalize docs for page_size / max_results / page_token.
- from 1.13.1
  * Implementation Changes
  - Import iam.policy from google.api_core.
  - Accomodate new back-end restriction on retention period.
  - Avoid deleting a blob renamed to itself
  * Dependencies
  - Update dependency to google-cloud-core
  - Bump minimum api_core version for all GAPIC libs to 1.4.1.
  * Documentation
  - Normalize use of support level badges
  * Internal / Testing Changes
  - Blacken libraries
  - Add templates for flake8, coveragerc, noxfile, and black.
  - Harden teardown in system tests.
  - Harden create_bucket call in systests vs. 429 TooManyRequests.
  - Skip public bucket test in VPC Service Controls
  - Fix lint failure.
  - Disable test running in VPC Service Controls restricted environment
  - Use new Nox
- from 1.13.0
  * New Features
  - Add support for bucket retention policies
  - Allow destination.content_type to be None in Blob.compose.
  * Implementation Changes
  - Ensure that method for Blob.generate_signed_url is uppercase.
  * Documentation
  - Clarify GCS URL signing limitations on GCE
  - Redirect renamed 'usage.html'/'client.html' -> 'index.html'.
- from 1.12.0
  * New Features
  - Add support for Python 3.7, drop support for Python 3.4.
  - Add lifecycle rules helpers to bucket.
  * Implementation Changes
  - Add 'stacklevel=2' to deprecation warnings.
  * Documentation
  - Storage docs: fix typos.
  - Prep storage docs for repo split.
  * Internal / Testing Changes
  - Harden systest teardown further.
  - Nox: use inplace installs
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Fri May 18 2018 tbechtold@suse.com
- Initial packaging (version 1.11.0)
